#! /bin/sh
#
# Name: deliver_cdbs.s
#
# Description: Runs the steps involved in delivering a new set of CDBS
#              reference files to the system.  These include
#
#                 certifying that the files contained expected parameters
#                 verifying that FITS files are in proper FITS format
#                 verifying that the DB load files have reasonable content
#                 generating a file of SQL for loading the CDBS database
#                 applying the CDBS SQL to the CDBS database
#                 running various consistency checks against the CDBS DB
#                 updating the general_availability_date for this delivery
#                 generating an OPUS catalog for the delivery (.cat file)
#
#              A failure during any of the steps will halt the delivery
#              process.  Depending on how far the delivery progressed before
#              the error occurred, it may be necessary to run the
#              "delete_delivery" task to clear the failed delivery from the
#              system before correcting the problem and attempting the
#              delivery again.
#
# Called by:   sendit
#
# Returns: 0 = no errors encountered in the delivery steps
#          1 = one of the delivery steps failed
#
#-------------------------------------------------------------------------
echo "starting deliver_cdbs"
echo "database " ${CDBS_DB?"CDBS_ERROR: CDBS_DB is undefined"}
echo "server " ${CDBS_SERVER?"CDBS_ERROR: CDBS_SERVER is undefined"}
date
#
for task in certify_delivery \
            fitsverify_delivery \
            check_load \
            cdbs_sql_gen.sh \
            run_delivery_sql \
            check_cdbs \
            update_ga_date \
            opus_catalog 
  do 
     echo "---------------------------------------------"
     $task
     if test $? -ne 0
     then
       echo "CDBS ERROR: $task failure. Exiting."
       exit 1
     fi
     echo "$task succeeded"
  done

echo "---------------------------------------------"
echo "deliver_cdbs completed"
date
echo " "
exit 0
